@@ -3,7 +3,7 @@ from kaa.command import Commands, command, is_enable, norec, norerun
 from kaa import document
 
 #todo: following imports should be defered
-from kaa.ui.mainmenu import mainmenumode
+from kaa.ui.mainmenu import menumode
 from kaa.ui.itemlist import itemlistmode
 from kaa.ui.moveseparator import moveseparatormode
 
@@ -12,58 +12,43 @@ class ApplicationCommands(Commands):
     @norec
     @norerun
     def show_mainmenu(self, wnd):
-        doc = mainmenumode.MainMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=True)
-
-    @command('menu.file')
-    @norec
-    @norerun
-    def show_filemenu(self, wnd):
-        doc = mainmenumode.FileMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
-
-    @command('menu.recently-used-files')
-    @norec
-    @norerun
-    def show_recentfilesmenu(self, wnd):
-        doc = mainmenumode.RecentlyUsedFileMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
-
-    @command('menu.edit')
-    @norec
-    @norerun
-    def show_editmenu(self, wnd):
-        doc = mainmenumode.EditMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
+        menumode.MenuMode.show_menu(wnd, 'MAIN')
 
     @command('menu.edit.convert')
     @norec
     @norerun
     def show_editmenuconvert(self, wnd):
-        doc = mainmenumode.EditMenuConvertMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
+        menumode.MenuMode.show_menu(wnd, 'EDIT-CONVERT')
 
-    @command('menu.macro')
-    @norerun
-    @norec
-    def show_macromenu(self, wnd):
-        doc = mainmenumode.MacroMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
+    def _walk_all_wnds(self, wnd):
+        yield wnd
+        curframe = wnd.get_label('frame')
+        if curframe:
+            for w in curframe.get_editors():
+                if w is not wnd:
+                    yield w
+        
+        for frame in kaa.app.get_frames():
+            if frame is not curframe:
+                for w in frame.get_editors():
+                    yield w
 
-    @command('menu.tools')
+    @command('app.global.prev')
     @norec
     @norerun
-    def show_toolsmenu(self, wnd):
-        doc = mainmenumode.ToolsMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
+    def global_prev(self, wnd):
+        for w in self._walk_all_wnds(wnd):
+            if w.document.mode.on_global_prev(w):
+                return
 
-    @command('menu.window')
+    @command('app.global.next')
     @norec
     @norerun
-    def show_windowmenu(self, wnd):
-        doc = mainmenumode.WindowMenuMode.build(wnd)
-        kaa.app.show_menu(wnd, doc, root=False)
-
+    def global_next(self, wnd):
+        for w in self._walk_all_wnds(wnd):
+            if w.document.mode.on_global_next(w):
+                return
+        
     # todo: move following methods somewhere else
 
     @command('app.show-framelist')
@@ -124,6 +109,18 @@ class ApplicationCommands(Commands):
                 n = len(wnds)-1
             wnds[n].activate()
 
+    def save_splitterdocs(self, wnd, splitter, callback):
+        wnds = set()
+        docs = set()
+        for child, w in splitter.walk():
+            if w:
+                wnds.add(w)
+                docs.add(w.document)
+
+        saves = [doc for doc in docs if wnds.issuperset(doc.wnds)]
+
+        wnd.document.mode.file_commands.save_documents(wnd, saves, callback)
+
     @command('editor.joinwindow')
     @norec
     def editor_joinwindow(self, wnd):
@@ -132,18 +129,10 @@ class ApplicationCommands(Commands):
             if not buddy:
                 return   # not split
 
-            wnds = set()
-            docs = set()
-            for splitter, w in buddy.walk():
-                if w:
-                    wnds.add(w)
-                    docs.add(w.document)
-
-            saves = [doc for doc in docs if wnds.issuperset(doc.wnds)]
             def saved():
                 wnd.splitter.parent.join(wnd)
 
-            wnd.document.mode.file_commands.save_documents(wnd, saves, saved)
+            self.save_splitterdocs(wnd, buddy, saved)
 
     @command('editor.switchfile')
     @norec
