@@ -358,13 +358,7 @@ class EditCommands(Commands):
             return
 
         wnd.screen.selection.clear()
-
-        pos = wnd.cursor.pos
-        indent = wnd.document.mode.get_auto_indent(pos)
-        self.insert_string(wnd, pos, indent, update_cursor=False)
-
-        wnd.cursor.setpos(pos+len(indent))
-        wnd.cursor.savecol()
+        indent = wnd.document.mode.on_auto_indent(wnd)
 
     def _get_line_sel(self, wnd):
         doc = wnd.document
@@ -401,7 +395,7 @@ class EditCommands(Commands):
 
     @command('edit.indent')
     def indent(self, wnd):
-        if not wnd.screen.selection.is_started():
+        if not wnd.screen.selection.is_selected():
             self._indent_line(wnd, wnd.cursor.pos)
             return
 
@@ -425,8 +419,27 @@ class EditCommands(Commands):
         finally:
             wnd.document.undo.endblock()
 
+        wnd.cursor.setpos(wnd.screen.selection.start)
+        wnd.cursor.savecol()
+
+    def _dedent_line(self, wnd, pos):
+        mode = wnd.document.mode
+        f, t = mode.get_indent_range(pos)
+        _trace(f, t)
+        if f != t:
+            cols = mode.calc_cols(f, t)
+        else:
+            cols = 0
+
+        s = mode.build_indent_str(max(0, cols-mode.indent_width))
+        self.replace_string(wnd, f, t, s, True)
+
     @command('edit.dedent')
     def dedent(self, wnd):
+        if not wnd.screen.selection.is_selected():
+            self._dedent_line(wnd, wnd.cursor.pos)
+            return
+
         doc = wnd.document
         tol, eol = self._get_line_sel(wnd)
         wnd.screen.selection.set_range(tol, eol)
@@ -680,6 +693,8 @@ class SearchCommands(Commands):
     def searchnext(self, wnd):
         if not modebase.SearchOption.LAST_SEARCH:
             return
+        if not modebase.SearchOption.LAST_SEARCH.text:
+            return
         range = wnd.screen.selection.get_range()
         if range:
             start = range[0]+1
@@ -699,6 +714,8 @@ class SearchCommands(Commands):
     def searchprev(self, wnd):
         if not modebase.SearchOption.LAST_SEARCH:
             return
+        if not modebase.SearchOption.LAST_SEARCH.text:
+            return
         range = wnd.screen.selection.get_range()
         if range:
             start = range[1]-1
@@ -714,6 +731,20 @@ class SearchCommands(Commands):
                                                     modebase.SearchOption.LAST_SEARCH)
                 self._show_searchresult(wnd, ret)
 
+    @command('search.showgrep')
+    @norec
+    @norerun
+    def showgrep(self, wnd):
+        from kaa.ui.grep import grepdlgmode
+
+        buf = document.Buffer()
+        doc = document.Document(buf)
+        mode = grepdlgmode.GrepDlgMode(wnd)
+        doc.setmode(mode)
+        mode.build_document()
+
+        kaa.app.show_dialog(doc)
+
 
 class RerunCommand(Commands):
     @command('command.rerun')
