@@ -9,6 +9,9 @@ HIST_FILENAME = 'files'
 HIST_DIRNAME = 'dirs'
 HIST_SEARCH = 'searchstr'
 HIST_REPLACE = 'replstr'
+HIST_GREPSTR = 'grepstr'
+HIST_GREPDIR = 'grepdir'
+HIST_GREPFILES = 'grepfiles'
 
 NEWLINES = ['auto', 'dos', 'unix']
 NEWLINE_CHARS = {
