@@ -16,7 +16,6 @@ class CuiApp:
         self._idleprocs = None
         self.colors = color.Colors()
         self.lastcommands = ()
-        self.menus = []
         self.focus = None
         self.clipboard = ''
         self._quit = False
@@ -43,12 +42,20 @@ class CuiApp:
         self.config.hist_searchstr.load()
         self.config.hist_replstr.load()
 
+        self.config.hist_grepstr.load()
+        self.config.hist_grepdir.load()
+        self.config.hist_grepfiles.load()
+
     def on_shutdown(self):
         self.config.hist_files.save()
         self.config.hist_dirs.save()
         self.config.hist_searchstr.save()
         self.config.hist_replstr.save()
 
+        self.config.hist_grepstr.save()
+        self.config.hist_grepdir.save()
+        self.config.hist_grepfiles.save()
+
     def get_current_theme(self):
         return self._theme_name
 
@@ -136,25 +143,6 @@ class CuiApp:
         self.mainframe.show_dialog(dlg)
         return dlg
 
-    def show_menu(self, wnd, doc, root):
-        if root:
-            self.menus = [doc]
-        else:
-            self.menus.append(doc)
-        return self.show_dialog(doc)
-
-    def pop_menu(self):
-        if self.menus:
-            menu = self.menus.pop()
-            menu.close()
-
-        if self.menus:
-            doc = self.menus[-1]
-            self.show_dialog(doc)
-
-    def clear_menu(self):
-        self.menus = []
-
     def get_frames(self):
         return self.mainframe.childframes[:]
 
@@ -192,4 +180,5 @@ class CuiApp:
                 kaa.log.error('Unhandled exception', exc_info=True)
                 kaa.app.messagebar.set_message(str(e))
 
+                nonblocking = False
 
