@@ -47,7 +47,7 @@ def main(stdscr):
 
     _init(stdscr)
     try:
-        keydef.init()
+        keydef.init(conf)
 
         kaa.app = app.CuiApp(conf)
         kaa.app.storage = fileio.FileStorage()
@@ -92,7 +92,7 @@ def main(stdscr):
 
     finally:
         _restore()
-
+        _trace('end')
 def run():
     if sys.version_info[:2] < (3, 3):
         raise RuntimeError('kaa requires Python 3.3 or later')
