@@ -6,13 +6,31 @@ from kaa.filetype.default import defaultmode
 from kaa import consts
 
 class FileStorage:
-    def get_textio(self, *args, **kwargs):
+    def get_textio(self, fileinfo):
         try:
-            return open(*args, **kwargs)
+            # use surrogateescape to preserve file contents intact.
+            textio = open(fileinfo.fullpathname, 'r',
+                        encoding=fileinfo.encoding, 
+                        errors='surrogateescape', 
+                        newline=fileinfo.nlchars)
+        
         except FileNotFoundError:
             return None
 
-    def set_fileinfo(self, fileinfo, filename):
+        return textio
+
+    def get_fileinfo(self, filename, encoding=None, newline=None):
+        if sys.platform == 'darwin':
+            filename = unicodedata.normalize('NFC', filename)
+    
+        if encoding is None:
+            encoding = kaa.app.config.DEFAULT_ENCODING
+    
+        if newline is None:
+            newline = kaa.app.config.DEFAULT_NEWLINE
+    
+        fileinfo = FileInfo()
+
         fullpath = os.path.abspath(filename)
         dirname, filename = os.path.split(filename)
 
@@ -25,8 +43,12 @@ class FileStorage:
             fileinfo.stat = os.stat(filename)
         except FileNotFoundError:
             fileinfo.stat = None
-        return fileinfo
 
+        fileinfo.encoding = encoding
+        fileinfo.newline = newline
+        
+        return fileinfo
+        
     def listdir(self, dirname):
         dirs = []
         files = []
@@ -50,8 +72,9 @@ class FileStorage:
         kaa.app.config.hist_dirs.add(dirname)
         kaa.app.last_dir = dirname
 
-    def openfile(self, filename, encoding=None, newline=None):
-        self._save_hist(filename)
+    def openfile(self, filename, encoding=None, newline=None, nohist=False):
+        if not nohist:
+            self._save_hist(filename)
         return openfile(filename, encoding, newline)
 
     def save_document(self, filename, doc):
@@ -67,11 +90,11 @@ class FileStorage:
                  newline=consts.NEWLINE_CHARS[doc.fileinfo.newline],
                  errors='surrogateescape') as f:
 
-            # TODO: save as another file and rename?
+            # TODO: save as another file and rename.
             # TODO: fsync
             f.write(doc.gettext(0, doc.endpos()))
 
-        self.set_fileinfo(doc.fileinfo, filename)
+        doc.fileinfo = self.get_fileinfo(filename)
         doc.provisional = False
         if doc.undo:
             doc.undo.saved()
@@ -96,6 +119,10 @@ class FileInfo:
     encoding = None
     newline = None
 
+    @property
+    def nlchars(self):
+        return consts.NEWLINE_CHARS[self.newline]
+
     def __init__(self):
         self.encoding = kaa.app.config.DEFAULT_ENCODING
         self.newline= kaa.app.config.DEFAULT_NEWLINE
@@ -112,29 +139,14 @@ def select_mode(filename):
 
 def openfile(filename, encoding=None, newline=None):
     # Open file
-    if sys.platform == 'darwin':
-        filename = unicodedata.normalize('NFC', filename)
-
-    if encoding is None:
-        encoding = kaa.app.config.DEFAULT_ENCODING
-
-    if newline is None:
-        newline = kaa.app.config.DEFAULT_NEWLINE
-
-    fileinfo = FileInfo()
-    kaa.app.storage.set_fileinfo(fileinfo, filename)
-    fileinfo.encoding = encoding
-    fileinfo.newline = newline
-    nlchars = consts.NEWLINE_CHARS[newline]
-    # use surrogateescape to preserve file contents intact.
-    textio = kaa.app.storage.get_textio(fileinfo.fullpathname, 'r', encoding=encoding,
-                                errors='surrogateescape', newline=nlchars)
+    fileinfo = kaa.app.storage.get_fileinfo(filename, encoding, newline)
+    textio = kaa.app.storage.get_textio(fileinfo)
 
     buf = document.Buffer()
     if textio:
         src = textio.read()
-        if nlchars is not None:
-            src = src.replace(nlchars, '\n')
+        if fileinfo.nlchars is not None:
+            src = src.replace(fileinfo.nlchars, '\n')
         buf.insert(0, src)
 
     doc = document.Document(buf)
