@@ -4,6 +4,8 @@ from kaa.keyboard import *
 app_keys = {
     (alt, '/'): 'app.mainmenu',
     f1: 'app.mainmenu',
+    f9: 'app.global.prev',
+    f10: 'app.global.next',
 }
 
 # default cursor commands
@@ -66,8 +68,8 @@ edit_command_keys = {
     (ctrl, 'w'): 'edit.cut',
     (alt, 'w'): 'edit.copy',
     (ctrl, 'y'): 'edit.paste',
-    (ctrl, '_'): 'edit.undo',
-    (alt, '_'): 'edit.redo',
+    (ctrl, 'u'): 'edit.undo',
+    (alt, 'u'): 'edit.redo',
 
 }
 
@@ -96,9 +98,8 @@ rerun_keys = {
 search_command_keys = {
     (ctrl, 's'): 'search.showsearch',
     (alt, 's'): 'search.showreplace',
+    f2: 'search.prev',
     f3: 'search.next',
-    f4: 'search.prev',
-
 }
 
 # emacs like keys
