@@ -9,24 +9,33 @@ from kaa import theme
 from kaa import screen
 
 class SearchOption:
+    RE = gappedbuf.re
     def __init__(self):
         self.text = ''
         self.ignorecase = True
         self.word = False
         self.regex = False
 
+    def clone(self):
+        ret = self.__class__()
+        ret.text = self.text
+        ret.ignorecase = self.ignorecase
+        ret.word = self.word
+        ret.regex = self.regex
+        return ret
+        
     def get_regex(self):
         text = self.text
         if not self.regex:
-            text = gappedbuf.re.escape(text)
+            text = self.RE.escape(text)
         if self.word:
             text = r'\b'+text+r'\b'
 
-        opt = gappedbuf.re.MULTILINE
+        opt = self.RE.MULTILINE
         if self.ignorecase:
-            opt += gappedbuf.re.IGNORECASE
+            opt += self.RE.IGNORECASE
 
-        regex = gappedbuf.re.compile(text, opt)
+        regex = self.RE.compile(text, opt)
         return regex
 
 SearchOption.LAST_SEARCH = SearchOption()
@@ -35,10 +44,12 @@ class ModeBase:
     CLOSE_ON_DEL_WINDOW = True
 
     SCREEN_NOWRAP = False
+    NO_WRAPINDENT = False
     SCREEN_BUILD_ENTIRE_ROWS = False
     SHOW_LINENO = False
     USE_UNDO = True
     DOCUMENT = False
+    HIGHLIGHT_CURSORLINE = False
 
     tab_width = 8
     indent_width = 4
@@ -342,10 +353,21 @@ class ModeBase:
         else:
             return ' ' * col
 
-    def get_auto_indent(self, pos):
+    def on_auto_indent(self, wnd):
+        pos = wnd.cursor.pos
         f, t = self.get_indent_range(pos)
         indent = self.document.gettext(f, min(pos, t))
-        return '\n'+indent
+        if pos <= t:
+            self.edit_commands.insert_string(wnd, f, '\n', 
+                    update_cursor=False)
+            wnd.cursor.setpos(wnd.cursor.pos+1)
+        else:
+            indent = '\n'+indent
+            self.edit_commands.insert_string(wnd, pos, indent, 
+                    update_cursor=False)
+            wnd.cursor.setpos(pos+len(indent))
+        
+        wnd.cursor.savecol()
 
     def calc_cols(self, f, t):
         chars = self.document.gettext(f, t)
@@ -354,3 +376,9 @@ class ModeBase:
 
         return sum(dispcols)
 
+    def on_global_next(self, wnd):
+        return
+
+    def on_global_prev(self, wnd):
+        return
+ 
\ No newline at end of file
