@@ -75,6 +75,15 @@ class FileInfoMode(dialogmode.DialogMode):
         f.append_text('default', ' {}\n'.format(
             fileinfo.newline if fileinfo else ''))
 
+        f.append_text('caption', '  Line number: ')
+        f.append_text('default', ' {}       '.format(
+            'Show' if mode.SHOW_LINENO else 'Hide'))
+        f.append_text('button', '[Change &Line number]\n',
+                      on_shortcut=self._on_update_lineno,
+                      shortcut_style='shortcut',
+                      shortcut_need_alt=False)
+
+
         f.append_text('default', '\n')
 
         f.append_text('caption', '    Tab width: ',
@@ -133,6 +142,9 @@ class FileInfoMode(dialogmode.DialogMode):
         names = [mode.MODENAME for mode in modes]
 
         def callback(n):
+            if n is None:
+                return
+
             mode = modes[n]
             if mode is not type(self.target.document.mode):
                 self.target.document.setmode(mode())
@@ -146,9 +158,32 @@ class FileInfoMode(dialogmode.DialogMode):
 
         kaa.app.show_dialog(doc)
 
+    def _on_update_lineno(self, c):
+        values = ['Hide', 'Show']
+        def callback(n):
+            if n is None:
+                return
+
+            v = bool(n)
+            if self.target.document.mode.SHOW_LINENO != v:
+                self.target.document.mode.SHOW_LINENO = v
+                self.target.document.update_screen(0, 0, 0)
+                self.build_doc()
+
+        doc = itemlistmode.ItemListMode.build(
+            'Use tab for indent?',
+            values,
+            int(self.target.document.mode.SHOW_LINENO),
+            callback)
+
+        kaa.app.show_dialog(doc)
+
     def _on_update_tab(self, c):
         values = [str(i) for i in range(2, 9)]
         def callback(n):
+            if n is None:
+                return
+
             width = int(values[n])
             if self.target.document.mode.tab_width != width:
                 self.target.document.mode.tab_width = width
@@ -166,6 +201,9 @@ class FileInfoMode(dialogmode.DialogMode):
     def _on_update_indent(self, c):
         values = [str(i) for i in range(2, 9)]
         def callback(n):
+            if n is None:
+                return
+
             width = int(values[n])
             if self.target.document.mode.indent_width != width:
                 self.target.document.mode.indent_width = width
@@ -181,8 +219,11 @@ class FileInfoMode(dialogmode.DialogMode):
         kaa.app.show_dialog(doc)
 
     def _on_update_usetab(self, c):
-        values = ['no', 'yes']
+        values = ['No', 'Yes']
         def callback(n):
+            if n is None:
+                return
+
             v = bool(n)
             if self.target.document.mode.indent_tab != v:
                 self.target.document.mode.indent_tab = v
@@ -200,6 +241,9 @@ class FileInfoMode(dialogmode.DialogMode):
     def _on_update_autoindent(self, c):
         values = ['No', 'Yes']
         def callback(n):
+            if n is None:
+                return
+
             v = bool(n)
             if self.target.document.mode.auto_indent != v:
                 self.target.document.mode.auto_indent = v
