@@ -56,18 +56,7 @@ class SearchCommands(editorcommand.EditCommands):
 
     
     def _show_histdlg(self, wnd, title, candidates, callback):
-        doc = filterlist.FilterListInputDlgMode.build(
-                title, callback)
-        dlg = kaa.app.show_dialog(doc)
-    
-        filterlistdoc = filterlist.FilterListMode.build()
-        dlg.add_doc('dlg_filterlist', 0, filterlistdoc)
-        
-        filterlistdoc.mode.set_candidates(candidates)
-    
-        list = dlg.get_label('dlg_filterlist')
-        filterlistdoc.mode.set_query(list, '')
-        dlg.on_console_resized()
+        filterlist.show_listdlg(title, candidates, callback)
         
     @command('searchdlg.history')
     @norec
@@ -77,6 +66,7 @@ class SearchCommands(editorcommand.EditCommands):
             if result:
                 f, t = wnd.document.marks['searchtext']
                 wnd.document.replace(f, t, result)
+                wnd.cursor.setpos(f)
             
         self._show_histdlg(wnd, 'Recent searches', 
                 kaa.app.config.hist_searchstr, callback)
@@ -128,6 +118,12 @@ class SearchDlgMode(dialogmode.DialogMode):
         self.lasthit = None
         self.option = modebase.SearchOption.LAST_SEARCH
 
+        if target and target.screen.selection.is_selected():
+            f, t = target.screen.selection.get_range()
+            s = target.document.gettext(f, t).split('\n')
+            if s:
+                self.option.text = s[0].strip()
+
     def close(self):
         super().close()
         self.target = None
@@ -267,7 +263,10 @@ class SearchDlgMode(dialogmode.DialogMode):
     def on_edited(self, wnd):
         self.lastsearch = None
         self.lasthit = None
-        self._search_next(wnd)
+        if not self._search_next(wnd):
+            self.lastsearch = -1
+            self._search_next(wnd)
+            
 
     def _show_searchresult(self, hit):
         if hit:
@@ -281,7 +280,9 @@ class SearchDlgMode(dialogmode.DialogMode):
 
     def _search_next(self, wnd):
         self.option.text = self.get_search_str()
-        if self.option.text:
+        if not self.option.text:
+            self.target.screen.selection.clear()
+        else:
             if self.lasthit is self.lastsearch is None:
                 # initial search
                 if self.initialrange:
@@ -348,13 +349,6 @@ class SearchDlgMode(dialogmode.DialogMode):
         self.target = None
         wnd.get_label('popup').destroy()
 
-    def on_document_updated(self, pos, inslen, dellen):
-        super().on_document_updated(pos, inslen, dellen)
-        if self.lastsearch:
-            newstr = self.get_search_str()
-            if newstr != self.option.text:
-                self.lastsearch = None
-
 
 class ReplaceCommands(SearchCommands):
     @command('replacedlg.field.next')
@@ -376,9 +370,10 @@ class ReplaceCommands(SearchCommands):
             if result:
                 f, t = wnd.document.marks['replacetext']
                 wnd.document.replace(f, t, result)
-            
-        self._show_histdlg(wnd, 'Recent searches', 
-                kaa.app.config.hist_searchstr, callback)
+                wnd.cursor.setpos(f)
+                
+        self._show_histdlg(wnd, 'Recent replace strings', 
+                kaa.app.config.hist_replstr, callback)
 
     @command('replacedlg.history')
     @norec
